Clazz.declarePackage("J.rendersurface");
Clazz.load(["J.rendersurface.IsosurfaceRenderer"], "J.rendersurface.ContactRenderer", null, function(){
var c$ = Clazz.declareType(J.rendersurface, "ContactRenderer", J.rendersurface.IsosurfaceRenderer);
});
;//5.0.1-v7 Sun May 18 17:15:27 CDT 2025
